@@ -36,6 +36,14 @@ from classes import info
 from classes import settings
 
 
+try:
+    from language import openshot_lang
+    language_path=":/locale/"
+    log.debug("Using compiled translation resources")
+except ImportError:
+    language_path=os.path.join(info.PATH, 'language')
+    log.debug("Loading translations from: {}".format(language_path))
+
 def init_language():
     """ Find the current locale, and install the correct translators """
 
@@ -45,20 +53,20 @@ def init_language():
     # Setup of our list of translators and paths
     translator_types = (
         {"type": 'QT',
-         "pattern": 'qt_%s',        # Older versions of Qt use this file (built-in translations)
+         "prefix": 'qt_',        # Older versions of Qt use this file (built-in translations)
          "path": QLibraryInfo.location(QLibraryInfo.TranslationsPath)},
         {"type": 'QT',
-         "pattern": 'qtbase_%s',    # Newer versions of Qt use this file (built-in translations)
+         "prefix": 'qtbase_',    # Newer versions of Qt use this file (built-in translations)
          "path": QLibraryInfo.location(QLibraryInfo.TranslationsPath)},
         {"type": 'QT',
-         "pattern": 'qt_%s',
-         "path": os.path.join(info.PATH, 'locale', 'QT')}, # Optional path where we package QT translations
+         "prefix": 'qt_',
+         "path": os.path.join(info.PATH, 'language')}, # Optional path where we package QT translations
         {"type": 'QT',
-         "pattern": 'qtbase_%s',
-         "path": os.path.join(info.PATH, 'locale', 'QT')}, # Optional path where we package QT translations
+         "prefix": 'qtbase_',
+         "path": os.path.join(info.PATH, 'language')}, # Optional path where we package QT translations
         {"type": 'OpenShot',
-         "pattern": os.path.join('%s', 'LC_MESSAGES', 'OpenShot'),  # Our custom translations
-         "path": os.path.join(info.PATH, 'locale')},
+         "prefix": 'OpenShot.',  # Our custom translations
+         "path": language_path},
     )
 
     # Determine the environment locale, or default to system locale name
@@ -66,16 +74,28 @@ def init_language():
                     os.environ.get('LOCALE', QLocale().system().name())
                     ]
 
-    # Determine if the user has overwritten the language (in the preferences)
+    # Get the user's configured language preference
     preference_lang = settings.get_settings().get('default-language')
-    if preference_lang != "Default":
-        # Append preference lang to top of list
+
+    # Output all languages detected from various sources
+    log.info("Qt Detected Languages: {}".format(QLocale().system().uiLanguages()))
+    log.info("LANG Environment Variable: {}".format(os.environ.get('LANG', "")))
+    log.info("LOCALE Environment Variable: {}".format(os.environ.get('LOCALE', "")))
+    log.info("OpenShot Preference Language: {}".format(preference_lang))
+
+    # Check if the language preference is something other than "Default"
+    if preference_lang == "en_US":
+        # Override language list with en_US, don't add to it
+        locale_names = [ "en_US" ]
+    elif preference_lang != "Default":
+        # Prepend preference setting to list
         locale_names.insert(0, preference_lang)
 
-    # Output all system languages detected
-    log.info("Qt Detected Languages: {}".format(QLocale().system().uiLanguages()))
-    log.info("LANG Environment Variable: {}".format(os.environ.get('LANG', QLocale().system().name())))
-    log.info("LOCALE Environment Variable: {}".format(os.environ.get('LOCALE', QLocale().system().name())))
+    # If the user has used the --lang command line arg, override with that
+    # (We've already checked that it's in SUPPORTED_LANGUAGES)
+    if info.CMDLINE_LANGUAGE:
+        locale_names = [ info.CMDLINE_LANGUAGE ]
+        log.info("Language overridden on command line, using: {}".format(info.CMDLINE_LANGUAGE))
 
     # Default the locale to C, for number formatting
     locale.setlocale(locale.LC_ALL, 'C')
@@ -84,96 +104,39 @@ def init_language():
     found_language = False
     for locale_name in locale_names:
 
-        # Don't try on default locale, since it fails to load what is the default language
-        if QLocale().system().name() in locale_name:
-            log.info("Skipping English language (no need for translation): {}".format(locale_name))
-            continue
-
         # Go through each translator and try to add for current locale
         for type in translator_types:
             trans = QTranslator(app)
-            if find_language_match(type["pattern"], type["path"], trans, locale_name):
+            if find_language_match(type["prefix"], type["path"], trans, locale_name):
                 # Install translation
                 app.installTranslator(trans)
                 found_language = True
 
-        # Exit if found language
+        # Exit if found language for type: "OpenShot"
         if found_language:
-            log.info("Exiting translation system (since we successfully loaded: {})".format(locale_name))
+            log.debug("Exiting translation system (since we successfully loaded: {})".format(locale_name))
             info.CURRENT_LANGUAGE = locale_name
             break
 
 
-def get_current_locale():
-    """Get the current locale name from the current system"""
-
-    # Get app instance
-    app = QCoreApplication.instance()
-
-    # Setup of our list of translators and paths
-    translator_types = (
-        {"type": 'QT',
-         "pattern": 'qt_%s',
-         "path": QLibraryInfo.location(QLibraryInfo.TranslationsPath)},
-        {"type": 'OpenShot',
-         "pattern": os.path.join('%s', 'LC_MESSAGES', 'OpenShot'),
-         "path": os.path.join(info.PATH, 'locale')},
-    )
-
-    # Determine the environment locale, or default to system locale name
-    locale_names = [os.environ.get('LANG', QLocale().system().name()),
-                    os.environ.get('LOCALE', QLocale().system().name())
-                    ]
-
-    # Loop through environment variables
-    found_language = False
-    for locale_name in locale_names:
-
-        # Don't try on default locale, since it fails to load what is the default language
-        if 'en_US' in locale_name:
-            continue
-
-        # Go through each translator and try to add for current locale
-        for type in translator_types:
-            trans = QTranslator(app)
-            if find_language_match(type["pattern"], type["path"], trans, locale_name):
-                found_language = True
-
-        # Exit if found language
-        if found_language:
-            return locale_name.replace(".UTF8", "").replace(".UTF-8", "")
-
-    # default locale
-    return "en"
-
 # Try the full locale and base locale trying to find a valid path
 #  returns True when a match was found.
 #  pattern - a string expected to have one pipe to be filled by locale strings
 #  path - base path for file (pattern may contain more path)
 #  
-def find_language_match(pattern, path, translator, locale_name):
+def find_language_match(prefix, path, translator, locale_name):
     """ Match all combinations of locale, language, and country """
 
-    success = False
-    locale_parts = locale_name.split('_')
-
-    i = len(locale_parts)
-    while not success and i > 0:
-        formatted_name = pattern % "_".join(locale_parts[:i])
-        log.info('Attempting to load {} in \'{}\''.format(formatted_name, path))
-        success = translator.load(formatted_name, path)
-        if success:
-            log.info('Successfully loaded {} in \'{}\''.format(formatted_name, path))
-        i -= 1
-
+    filename = prefix + locale_name
+    log.debug('Attempting to load {} in \'{}\''.format(filename,path))
+    success = translator.load(filename, path)
+    if success:
+        log.debug('Successfully loaded {} in \'{}\''.format(filename, path))
     return success
 
 def get_all_languages():
     """Get all language names and countries packaged with OpenShot"""
 
-    # Get app instance
-    app = QCoreApplication.instance()
-
     # Loop through all supported language locale codes
     all_languages = []
     for locale_name in info.SUPPORTED_LANGUAGES:
@@ -187,3 +150,7 @@ def get_all_languages():
 
     # Return list
     return all_languages
+
+def get_current_locale():
+    return info.CURRENT_LANGUAGE
+
