@@ -40,12 +40,12 @@ var track_container_height = -1;
 // 1: can be dragged
 // 2: can be resized
 // 3: class change when hovered over
-var dragLog = null;
+var dragLoc = null;
 
 App.directive('tlClip', function($timeout){
 	return {
 		scope: "@",
-		link: function(scope, element, attrs){
+		link: function(scope, element, attrs) {
 
 			//handle resizability of clip
 			element.resizable({ 
@@ -60,20 +60,23 @@ App.directive('tlClip', function($timeout){
 					var mouseLoc = e.pageX - parentOffset.left;
 					if (mouseLoc < 5) {
 						dragLoc = 'left';
-					} else {
+					} 
+					else {
 						dragLoc = 'right';
 					}
 
 					// Does this bounding box overlap a locked track?
-					if (hasLockedTrack(scope, e.pageY, e.pageY))
+					if (hasLockedTrack(scope, e.pageY, e.pageY)) {
 						return !event; // yes, do nothing
+					}
 
 					// Does this bounding box overlap a locked track?
 					var vert_scroll_offset = $("#scrolling_tracks").scrollTop();
 					var track_top = (parseInt(element.position().top) + parseInt(vert_scroll_offset));
 					var track_bottom = (parseInt(element.position().top) + parseInt(element.height()) + parseInt(vert_scroll_offset));
-					if (hasLockedTrack(scope, track_top, track_bottom))
+					if (hasLockedTrack(scope, track_top, track_bottom)) {
 						resize_disabled = true;
+					}
 
 					// Hide keyframe points
 					element.find('.point_icon').fadeOut('fast');
@@ -105,56 +108,58 @@ App.directive('tlClip', function($timeout){
 					new_left = scope.clip.start;
 					new_right = scope.clip.end;
 
-					if (dragLoc == 'left'){
+					if (dragLoc == 'left') {
 						// changing the start of the clip
 						new_left += delta_time;
 						if (new_left < 0) {
 							// prevent less than zero
 							new_left = 0.0;
 							new_position -= scope.clip.start
-						} else {
+						} 
+						else {
 							new_position += delta_time
 						}
-					} else {
+					} 
+					else {
 						// changing the end of the clips
 						new_right -= delta_time;
-						if (new_right > scope.clip.duration)
+						if (new_right > scope.clip.duration) {
 						    // prevent greater than duration
 							new_right = scope.clip.duration;
+						}
 					}
 
 					//apply the new start, end and length to the clip's scope
-					scope.$apply(function(){
+					scope.$apply(function() {
+						// Get the nearest starting frame position to the clip position (this helps to prevent cutting
+						// in-between frames, and thus less likely to repeat or skip a frame).
+						new_position = (Math.round((new_position * scope.project.fps.num) / scope.project.fps.den ) * scope.project.fps.den ) / scope.project.fps.num;
+						new_right = (Math.round((new_right * scope.project.fps.num) / scope.project.fps.den ) * scope.project.fps.den ) / scope.project.fps.num;
+						new_left = (Math.round((new_left * scope.project.fps.num) / scope.project.fps.den ) * scope.project.fps.den ) / scope.project.fps.num;
 
-						if (scope.clip.end != new_right){
+						if (scope.clip.end != new_right) {
 							scope.clip.end = new_right;
 						}
-						if (scope.clip.start != new_left){
+						if (scope.clip.start != new_left) {
 							scope.clip.start = new_left;
 							scope.clip.position = new_position;
 						}
-
-					// Resize timeline if it's too small to contain all clips
-					scope.ResizeTimeline();
+						// Resize timeline if it's too small to contain all clips
+						scope.ResizeTimeline();
 
 						// update clip in Qt (very important =)
-            			if (scope.Qt)
-            				timeline.update_clip_data(JSON.stringify(scope.clip));
-
+            			if (scope.Qt) {
+            				timeline.update_clip_data(JSON.stringify(scope.clip), true, true, false);
+            			}
 					});
-
 					//resize the audio canvas to match the new clip width
-					if (scope.clip.show_audio){
-						element.find(".audio-container").show();
+					if (scope.clip.show_audio) {
 						//redraw audio as the resize cleared the canvas
 						drawAudio(scope, scope.clip.id);
 					}
-
 					dragLoc = null;
-
 				},
 				resize: function(e, ui) {
-
 					if (resize_disabled) {
 						// disabled, keep the item the same size
 						$(this).css(ui.originalPosition);
@@ -170,41 +175,41 @@ App.directive('tlClip', function($timeout){
 					new_left = scope.clip.start;
 					new_right = scope.clip.end;
 
-					if (dragLoc == 'left'){
+					if (dragLoc == 'left') {
 						// changing the start of the clip
 						new_left += delta_time;
 						if (new_left < 0) {
 							ui.element.width(ui.size.width + (new_left * scope.pixelsPerSecond));
 							ui.element.css("left", ui.position.left - (new_left * scope.pixelsPerSecond));
-						} else {
+						} 
+						else {
 							ui.element.width(ui.size.width);
 						}
-					} else {
+					} 
+					else {
 						// changing the end of the clips
 						new_right -= delta_time;
 						if (new_right > scope.clip.duration) {
-							new_right = scope.clip.duration - new_right; // difference from duration
-							ui.element.width(ui.size.width + (new_right * scope.pixelsPerSecond));
 
 							// change back to actual duration (for the preview below)
 							new_right = scope.clip.duration;
-						} else {
+							ui.element.width(new_right * scope.pixelsPerSecond);
+						} 
+						else {
 							ui.element.width(ui.size.width);
 						}
 					}
 
-
 					// Preview frame during resize
-					if (dragLoc == 'left'){
+					if (dragLoc == 'left') {
 						// Preview the left side of the clip
 						scope.PreviewClipFrame(scope.clip.id, new_left);
-					} else {
+					} 
+					else {
 						// Preview the right side of the clip
 						scope.PreviewClipFrame(scope.clip.id, new_right);
 					}
-
-				},
-
+				}
 			});
 	
 			//handle hover over on the clip
@@ -233,8 +238,7 @@ App.directive('tlClip', function($timeout){
 		        start: function(event, ui) {
 		        	previous_drag_position = null;
 		        	dragging = true;
-		        	if (!element.hasClass('ui-selected')) 
-		        	{
+		        	if (!element.hasClass('ui-selected')) {
 		        		// Clear previous selections?
 		        		var clear_selections = false;
 		        		if ($(".ui-selected").length > 0)
@@ -247,7 +251,8 @@ App.directive('tlClip', function($timeout){
 		        			scope.SelectTransition("", clear_selections);
 		        			scope.SelectClip(id, clear_selections);
 		        			
-		        		} else if (element.hasClass('transition')) {
+		        		} 
+		        		else if (element.hasClass('transition')) {
 							// Select this transition, unselect all others
 		        			scope.SelectClip("", clear_selections);
 		        			scope.SelectTransition(id, clear_selections);
@@ -265,24 +270,26 @@ App.directive('tlClip', function($timeout){
 
 		        	// Init all other selected clips (prepare to drag them)
 		        	$(".ui-selected").each(function(){
-		        		start_clips[$(this).attr('id')] = {"top": $(this).position().top + vert_scroll_offset,
-                                						   "left": $(this).position().left + horz_scroll_offset};
-                        move_clips[$(this).attr('id')] = {"top": $(this).position().top + vert_scroll_offset,
-                               							  "left": $(this).position().left + horz_scroll_offset};
+						// Init all clips whether selected or not
+						start_clips[$(this).attr('id')] = {"top": $(this).position().top + vert_scroll_offset,
+														   "left": $(this).position().left + horz_scroll_offset};
+						move_clips[$(this).attr('id')] = {"top": $(this).position().top + vert_scroll_offset,
+														  "left": $(this).position().left + horz_scroll_offset};
 
-                        //send clip to bounding box builder
-                        setBoundingBox($(this));
+						//send clip to bounding box builder
+						setBoundingBox(scope, $(this));
                     });
 					
 					// Does this bounding box overlap a locked track?
-					if (hasLockedTrack(scope, bounding_box.top, bounding_box.bottom) || scope.enable_razor)
+					if (hasLockedTrack(scope, bounding_box.top, bounding_box.bottom) || scope.enable_razor) {
 						return !event; // yes, do nothing
-		        	
+					}
 		        },
                 stop: function(event, ui) {
-
 					// Ignore clip-menu click
-					$( event.toElement ).one('.clip_menu', function(e){ e.stopImmediatePropagation(); } );
+					$( event.toElement ).one('.clip_menu', function(e) {
+						e.stopImmediatePropagation(); 
+					});
 
                 	// Hide snapline (if any)
                 	scope.HideSnapline();
@@ -290,13 +297,11 @@ App.directive('tlClip', function($timeout){
                 	// Clear previous drag position
 					previous_drag_position = null;
 					dragging = false;
-
 				},
                 drag: function(e, ui) {
                 	var previous_x = ui.originalPosition.left;
 					var previous_y = ui.originalPosition.top;
-					if (previous_drag_position != null)
-					{
+					if (previous_drag_position != null) {
 						// if available, override with previous drag position
 						previous_x = previous_drag_position.left;
 						previous_y = previous_drag_position.top;
@@ -318,21 +323,17 @@ App.directive('tlClip', function($timeout){
 					ui.position.left = results.position.left;
 					ui.position.top = results.position.top;
 
-    				// Move all other selected clips with this one
+    				// Move all other selected clips with this one if we have more than one clip
 	                $(".ui-selected").each(function(){
 	                	var newY = move_clips[$(this).attr('id')]["top"] + y_offset;
                         var newX = move_clips[$(this).attr('id')]["left"] + x_offset;
-
-						//update the clip location in the array
+ 						//update the clip location in the array
 	                	move_clips[$(this).attr('id')]['top'] = newY;
                         move_clips[$(this).attr('id')]['left'] = newX;
-
-						//change the element location
+ 						//change the element location
 						$(this).css('left', newX);
 				    	$(this).css('top', newY);
-
-				    });
-
+ 				    });
                 },
                 revert: function(valid) {
                     if(!valid) {
@@ -347,8 +348,6 @@ App.directive('tlClip', function($timeout){
                     }
                 }
 		      });
-
-
 		}
 	};
 });
@@ -371,7 +370,6 @@ App.directive('tlMultiSelectable', function(){
 				distance: 0,
 				cancel: '.effect-container,.transition_menu,.clip_menu',
 				selected: function( event, ui ) {
-
 					// Identify the selected ID and TYPE
 					var id = ui.selected.id;
 					var type = "";
@@ -381,16 +379,15 @@ App.directive('tlMultiSelectable', function(){
 						id = id.replace("clip_", "");
 						type = "clip";
 						item = findElement(scope.project.clips, "id", id);
-					} else if (id.match("^transition_")) {
+					} 
+					else if (id.match("^transition_")) {
 						id = id.replace("transition_", "");
 						type = "transition";
 						item = findElement(scope.project.effects, "id", id);
 					}
 					
-					if (scope.Qt)
-					{
+					if (scope.Qt) {
 						timeline.addSelection(id, type, false);
-
 						// Clear effect selections (if any)
 						timeline.addSelection("", "effect", true);
 					}
@@ -399,7 +396,6 @@ App.directive('tlMultiSelectable', function(){
 					item.selected = true;
 				},
 				unselected: function( event, ui ) {
-
 					// Identify the selected ID and TYPE
 					var id = ui.unselected.id;
 					var type = "";
@@ -409,15 +405,16 @@ App.directive('tlMultiSelectable', function(){
 						id = id.replace("clip_", "");
 						type = "clip";
 						item = findElement(scope.project.clips, "id", id);
-					} else if (id.match("^transition_")) {
+					} 
+					else if (id.match("^transition_")) {
 						id = id.replace("transition_", "");
 						type = "transition";
 						item = findElement(scope.project.effects, "id", id);
 					}
 					
-					if (scope.Qt)
+					if (scope.Qt) {
 						timeline.removeSelection(id, type);
-
+					}
 					// Update item state
 					item.selected = false;
 				},
@@ -430,9 +427,4 @@ App.directive('tlMultiSelectable', function(){
 			});
 		}
 	};
-});
-
-
-
-
-
+});
\ No newline at end of file
