@@ -32,11 +32,7 @@ from PyQt5.QtWidgets import QListView, QMenu
 from classes.app import get_app
 from windows.models.titles_model import TitlesModel
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
-
+import json
 
 class TitlesListView(QListView):
     """ A QListView QWidget used on the title editor window """
@@ -91,4 +87,4 @@ class TitlesListView(QListView):
         self.setTextElideMode(Qt.ElideRight)
 
         # Refresh view
-        self.refresh_view()
\ No newline at end of file
+        self.refresh_view()
